Scriptname _SLPSkyUIConfig extends SKI_ConfigBase  

;====================================================================================

GlobalVariable Property _SLPDmgToggle Auto

_SLPQuestScript Property _SLPQuest Auto

String[] Pages
String[] SleepwearList
String[] SleepHostileList

String ModName

Int RestartOption
Int SleepwearOption
Int SleepHostileOption
Int FollowerOption
Int SnoreVolOption
Int DmgOption

Int SleepHostile
Int Sleepwear

Float SnoreVol

Bool Restart
Bool Follower
Bool Dmg

;====================================================================================

Function ApplySettings()
	_SLPQuest.Sleepwear = Sleepwear
	_SLPQuest.SleepHostile = SleepHostile
	_SLPQuest.SnoreVol = SnoreVol
	_SLPQuest.Follower = Follower
	If Dmg
		_SLPDmgToggle.SetValue(1)
	Else
		_SLPDmgToggle.SetValue(0)
	EndIf
	If Restart
		_SLPQuest.Restart()
		Debug.Notification("Sleep Tight: Restarted")
		Restart = False
	EndIf
EndFunction

;====================================================================================

Event OnConfigInit()
	ModName = "Sleep Tight"

	Pages = New String[1]
	Pages[0] = "Options"

	SleepHostileList = New String[4]
	SleepHostileList[0] = "Disabled"
	SleepHostileList[1] = "Naked"
	SleepHostileList[2] = "Keep Chest"
	SleepHostileList[3] = "Random"

	SleepwearList = New String[4]
	SleepwearList[0] = "Disabled"
	SleepwearList[1] = "Naked"
	SleepwearList[2] = "Robed"
	SleepwearList[3] = "Random"

	Sleepwear = _SLPQuest.Sleepwear
	SleepHostile = _SLPQuest.SleepHostile
	SnoreVol = _SLPQuest.SnoreVol
	Follower = _SLPQuest.Follower
	If _SLPDmgToggle.GetValue() as Int
		Dmg = True
	Else
		Dmg = False
	EndIf
EndEvent

Event OnPageReset(String Page)
	If Page == ""
		LoadCustomContent("sleeptight/title.dds")
		Return
	Else
		UnloadCustomContent()
	EndIf
	If Page == "Options"
		SetCursorFillMode(TOP_TO_BOTTOM)
		AddHeaderOption("NPCs")
		SleepwearOption = AddMenuOption("Friendly Sleepwear", SleepwearList[Sleepwear])
		SleepHostileOption = AddMenuOption("Hostile Sleepwear", SleepHostileList[SleepHostile])
		FollowerOption = AddToggleOption("Follower Support", Follower)
		DmgOption = AddToggleOption("Cheap Shot", Dmg)

		SetCursorPosition(1)

		AddHeaderOption("Misc.")
		SnoreVolOption = AddSliderOption("Snore Volume", SnoreVol, "{1}")
		RestartOption = AddToggleOption("Restart", Restart)
	EndIf
EndEvent

;====================================================================================

Event OnOptionSelect(Int Option)
	If Option == RestartOption
		Restart = !Restart
		SetToggleOptionValue(RestartOption, Restart)
	ElseIf Option == FollowerOption
		Follower = !Follower
		SetToggleOptionValue(FollowerOption, Follower)
	ElseIf Option == DmgOption
		Dmg = !Dmg
		SetToggleOptionValue(DmgOption, Dmg)
	EndIf
EndEvent

;====================================================================================

Event OnOptionSliderOpen(Int Option)
	If Option == SnoreVolOption
		SetSliderDialogStartValue(SnoreVol)
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 1.0)
		SetSliderDialogInterval(0.1)
	EndIf
EndEvent

Event OnOptionSliderAccept(Int Option, Float Value)
	If Option == SnoreVolOption
		SnoreVol = Value
		SetSliderOptionValue(SnoreVolOption, SnoreVol, "{1}")
	EndIf
EndEvent

;====================================================================================

Event OnOptionMenuOpen(Int Option)
	If Option == SleepwearOption
		SetMenuDialogOptions(SleepwearList)
		SetMenuDialogStartIndex(Sleepwear)
		SetMenuDialogDefaultIndex(2)
	ElseIf Option == SleepHostileOption
		SetMenuDialogOptions(SleepHostileList)
		SetMenuDialogStartIndex(SleepHostile)
		SetMenuDialogDefaultIndex(2)
	EndIf
EndEvent

Event OnOptionMenuAccept(Int Option, Int Index)
	If Option == SleepwearOption
		Sleepwear = Index
		SetMenuOptionValue(SleepwearOption, SleepwearList[Sleepwear])
	ElseIf Option == SleepHostileOption
		SleepHostile = Index
		SetMenuOptionValue(SleepHostileOption, SleepHostileList[SleepHostile])
	EndIf
EndEvent

;====================================================================================

Event OnOptionHighlight(Int Option)
	If Option == SleepwearOption
		SetInfoText("Friendly NPCs will equip the selected option when sleeping. Restart the mod to apply changes immediately.")
	ElseIf Option == SleepHostileOption
		SetInfoText("Hostile NPCs such as bandits, warlocks, etc. in interiors will equip the selected option when sleeping. If 'Keep Chest' is selected, they will keep their chest armor equipped. Some hostiles may now be found sleeping at night. Restart the mod to apply changes immediately.")
	ElseIf Option == FollowerOption
		SetInfoText("Followers will remove all equipment before getting into bed in interiors. A 'Sleep Tight, Good Night Story' book can be crafted at a tanning rack with 1 ruined book then given to a specific follower to exempt him/her from this mod without turning this feature off for all followers.  Restart the mod to apply changes immediately.")
	ElseIf Option == SnoreVolOption
		SetInfoText("Set the volume of the snore/breathing sound effects.  Restart the mod to apply changes immediately. Default: 1.0")
	ElseIf Option == DmgOption
		SetInfoText("Sleeping and sitting NPCs take more damage when struck.")
	ElseIf Option == RestartOption
		SetInfoText("Restarts the mod after you exit the menus. Use this if you have any issues.")
	EndIf
EndEvent

;====================================================================================

Event OnConfigClose()
	ApplySettings()
EndEvent